@@ -42,7 +42,7 @@ from calculate.lib.utils.files import (
     readFileEx, DirectoryRCS, RCSError, readLinesFile)
 from calculate.lib.utils.mount import isMount
 from calculate.lib.utils.git import Git
-from calculate.builder.variables.action import Actions
+from .variables.action import Actions
 from calculate.lib.utils.portage import (ReposConf, EmergeLog,
                                          EmergeLogFiltered,
                                          EmergeLogNamedTask,
@@ -73,6 +73,7 @@ from os import path
 from .datavars import BuilderError
 from .emerge_fetch import EmergeFetcher, EmergeFetcherError
 from calculate.lib.utils.grub import GrubCommand
+from functools import reduce
 
 _ = lambda x: x
 from calculate.lib.cl_lang import (setLocalTranslate, getLazyLocalTranslate)
@@ -269,7 +270,7 @@ class Builder(Update):
                                                         x['release'],
                                                         x['arch'],
                                                         x['variant'])):
-                    info = grps.next()
+                    info = next(grps)
                     dist_key = "{dist}:{release}:{arch}:{variant}".format(**info)
                     try:
                         indexsystem.write("{dist};{release};{arch};"
@@ -391,7 +392,7 @@ class Builder(Update):
         worldfile_snapshot = self.get_world_snapshot_filename(builder_path)
         if not path.exists(worldfile_snapshot):
             with writeFile(worldfile_snapshot) as f:
-                f.write(readFileEx(worldfile, grab=True))
+                f.write(readFileEx(worldfile, grab=True).decode("UTF-8"))
         return True
 
     def world_diff(self, builder_path):
@@ -1317,37 +1318,33 @@ class Builder(Update):
                 os.makedirs(pkgDir)
             if path.exists(dbPkg) and path.exists(pkgDir):
                 # get pkg list from distro
-                pkgList = \
-                    reduce(lambda x, y: x + y,
-                           map(lambda x: map(
-                               lambda z: path.join(x, "%s.tbz2" % z),
-                               os.listdir(path.join(dbPkg, x))),
-                               os.listdir(dbPkg)), [])
+                pkgList = reduce(lambda x, y: x + y,
+                    ((path.join(x, "%s.tbz2" % z) for z 
+                        in os.listdir(path.join(dbPkg, x))) for x 
+                            in os.listdir(dbPkg)),  
+                    [])
                 # get binary packages
-                binList = \
-                    reduce(lambda x, y: x + y,
-                           map(lambda x: map(
-                               lambda z: path.join(x, z)[len(pkgDir) + 1:],
-                               os.listdir(path.join(x))),
-                               filter(lambda x: path.isdir(x),
-                                      map(lambda x: path.join(pkgDir, x),
-                                          os.listdir(pkgDir)))), [])
-
+                binList = reduce(lambda x, y: x + y,
+                    ((path.join(x, y)[len(pkgDir) + 1:] for y 
+                        in os.listdir(path.join(x))) for x 
+                        in (z for z in (path.join(pkgDir, o) for o 
+                        in os.listdir(pkgDir)) 
+                        if path.isdir(z))),
+                    [])
                 # remove files which in binary and not in db/pkg
                 removeList = list(set(binList) - set(pkgList))
                 if removeList:
                     removelist_str = ",".join(
                         path.basename(x) for x in removeList)
                     logger.info(removelist_str)
-                map(lambda x: os.unlink(x),
-                    map(lambda x: pathJoin(pkgDir, x),
-                        removeList))
+
+                map(lambda x: os.unlink(x), 
+                    (pathJoin(pkgDir, x) for x in removeList))
 
                 # remove empty directories
-                map(lambda x: os.rmdir(x),
-                    filter(lambda x: path.isdir(x) and not os.listdir(x),
-                           map(lambda x: path.join(pkgDir, x),
-                               os.listdir(pkgDir))))
+                map(lambda x: os.rmdir(x), (x for x in (path.join(pkgDir, y) for y 
+                    in os.listdir(pkgDir)) 
+                    if path.isdir(x) and not os.listdir(x)))
 
                 self.regenPackages(chrootPath, pkgDir[len(chrootPath):])
         except OSError as e:
@@ -1561,12 +1558,12 @@ class Builder(Update):
         for pathname, dirs, files in os.walk(devPath, topdown=False):
             map(lambda x: os.unlink(path.join(pathname, x)), files)
             map(lambda x: os.unlink(x) if path.islink(x) else os.rmdir(x),
-                map(lambda x: path.join(pathname, x), dirs))
+                (path.join(pathname, x) for x in dirs))
         for node, mode, dmode, major, minor in [
-            ("console", 0600, stat.S_IFCHR, 5, 1),
-            ("tty1", 0600, stat.S_IFCHR, 4, 1),
-            ("null", 0666, stat.S_IFCHR, 1, 3),
-            ("zero", 0666, stat.S_IFCHR, 1, 5)]:
+            ("console", 0o600, stat.S_IFCHR, 5, 1),
+            ("tty1", 0o600, stat.S_IFCHR, 4, 1),
+            ("null", 0o666, stat.S_IFCHR, 1, 3),
+            ("zero", 0o666, stat.S_IFCHR, 1, 5)]:
             nodePath = path.join(devPath, node)
             os.mknod(nodePath, mode | dmode, os.makedev(major, minor))
             os.chmod(nodePath, mode)
@@ -1961,10 +1958,12 @@ class Builder(Update):
                                      if all(y not in pretend for y in x)]
                     required_pkgs = list(set(chain(*required_pkgs)))
 
-                    clear_req_pkgs = filter(
-                        None, [x.strip() for x in system_ini.getVar(
-                            "automagic-clear",
-                            package["CATEGORY/PN"]).split(",")])
+                    clear_req_pkgs = [x for x 
+                        in [x.strip() for x 
+                            in system_ini.getVar("automagic-clear", 
+                            package["CATEGORY/PN"]).split(",")] 
+                        if x]
+
                     waste_pkgs = [x for x in clear_req_pkgs if
                                   all(y["CATEGORY/PN"] != x
                                       for y in required_pkgs)]
