@@ -26,8 +26,8 @@ from calculate.lib.datavars import ReadonlyVariable, HumanReadable, \
     ReadonlyTableVariable, FieldValue, VariableError, Variable, \
     VariableInterface
 from calculate.install.variables import system, X11, locale, audio
-import builder
-from action import Actions
+from . import builder
+from .action import Actions
 
 _ = lambda x: x
 
@@ -307,7 +307,7 @@ class VariableClBuilderX11VideoDrv(GrubOptionVariable,
     def choice(self):
         values = (X11.VariableOsInstallX11VideoAvailable.supported +
                   [self.default_video])
-        return map(lambda x: (x, self.driver_names.get(x, x)), values)
+        return [(x, self.driver_names.get(x, x)) for x in values]
 
 
 class VariableClBuilderAudio(GrubOptionVariable, audio.VariableOsAudio):
