@@ -122,7 +122,7 @@ class DataVarsBuilderLinux(linux.LinuxDataVars):
         if isinstance(image, distr.ContainerDistributive):
             c = image.get_information()
         else:
-            re_stage = re.compile("stage(\d)-(amd64|x86)-(\d{8}).tar.\w+")
+            re_stage = re.compile(r"stage(\d)-(amd64|x86)-(\d{8}).tar.\w+")
             m = re_stage.search(fn)
             if m:
                 map_arch = {'amd64': 'x86_64', 'x86': 'i686'}
@@ -404,8 +404,7 @@ class VariableClBuilderPortdirOverlay(ReadonlyVariable):
 
     def get(self):
         return [location
-                for name, location in
-                filter(None, self.Get('builder.cl_builder_repository_data'))
+                for name, location in (x for x in self.Get('builder.cl_builder_repository_data') if x)
                 if name not in ("portage", "gentoo")]
 
 
@@ -481,8 +480,8 @@ class VariableClBuilderSyncOverlayRep(ReadonlyVariable):
         else:
             dv = self.Get('cl_builder_linux_datavars')
         if dv:
-            return filter(lambda x: x not in ("portage", "gentoo"),
-                          dv.Get('cl_repository_name'))
+            return [x for x in dv.Get('cl_repository_name') 
+                if x not in ("portage", "gentoo")]
         else:
             return []
 
