@@ -27,7 +27,7 @@ from calculate.update import profile as update_profile
 
 from calculate.lib.cl_lang import setLocalTranslate
 from calculate.update.variables.update import DataVarsUpdateProfile
-from calculate.builder.variables.action import Actions
+from ..variables.action import Actions
 
 _ = lambda x: x
 setLocalTranslate('cl_builder3', sys.modules[__name__])
